@@ -45,6 +45,7 @@ static bool can_use_swap;
 static bool can_use_sys_cpu;
 static bool has_versioned_opts;
 static bool memory_is_cgroupv2;
+static __u32 host_personality;
 
 static volatile sig_atomic_t reload_successful;
 
@@ -73,6 +74,11 @@ bool liblxcfs_memory_is_cgroupv2(void)
 	return memory_is_cgroupv2;
 }
 
+__u32 liblxcfs_personality(void)
+{
+	return host_personality;
+}
+
 /* Define pivot_root() if missing from the C library */
 #ifndef HAVE_PIVOT_ROOT
 static int pivot_root(const char *new_root, const char *put_old)
@@ -424,7 +430,7 @@ __returns_twice pid_t lxcfs_raw_clone(unsigned long flags, int *pidfd)
 	}
 #elif defined(__ia64__)
 	/* On ia64 the stack and stack size are passed as separate arguments. */
-	return syscall(__NR_clone, flags | SIGCHLD, NULL, prctl_arg(0), pidfd);
+	return syscall(__NR_clone, flags | SIGCHLD, NULL, 0, pidfd);
 #else
 	return syscall(__NR_clone, flags | SIGCHLD, NULL, pidfd);
 #endif
@@ -919,6 +925,11 @@ static void __attribute__((constructor)) lxcfs_init(void)
 		goto broken_upgrade;
 	}
 
+	if (get_task_personality(getpid(), &host_personality) < 0) {
+		lxcfs_info("Failed to retrieve host personality");
+		goto broken_upgrade;
+	}
+
 	reload_successful = 1;
 	return;
 
