@@ -25,14 +25,6 @@
 #include "macro.h"
 #include "memory_utils.h"
 
-/*
- * append the given formatted string to *src.
- * src: a pointer to a char* in which to append the formatted string.
- * sz: the number of characters printed so far, minus trailing \0.
- * asz: the allocated size so far
- * format: string format. See printf for details.
- * ...: varargs. See printf for details.
- */
 /*
  * append the given formatted string to *src.
  * src: a pointer to a char* in which to append the formatted string.
@@ -537,6 +529,29 @@ int safe_uint64(const char *numstr, uint64_t *converted, int base)
 	return 0;
 }
 
+int safe_uint32(const char *numstr, uint32_t *converted, int base)
+{
+	char *err = NULL;
+	unsigned long uli;
+
+	while (isspace(*numstr))
+		numstr++;
+
+	if (*numstr == '-')
+		return -EINVAL;
+
+	errno = 0;
+	uli = strtoul(numstr, &err, base);
+	if (errno == ERANGE && uli == UINT32_MAX)
+		return -ERANGE;
+
+	if (err == numstr || *err != '\0')
+		return -EINVAL;
+
+	*converted = (uint32_t)uli;
+	return 0;
+}
+
 static int char_left_gc(const char *buffer, size_t len)
 {
 	size_t i;
@@ -634,3 +649,45 @@ char *read_file_at(int dfd, const char *fnam, unsigned int o_flags)
 
 	return move_ptr(buf);
 }
+
+DIR *opendir_flags(const char *path, int flags)
+{
+	__do_close int dfd = -EBADF;
+	DIR *dirp;
+
+	dfd = open(path, O_DIRECTORY | flags);
+	if (dfd < 0)
+		return NULL;
+
+	dirp = fdopendir(dfd);
+	if (dirp)
+		move_fd(dfd); /* Transfer ownership to fdopendir(). */
+
+	return dirp;
+}
+
+int get_task_personality(pid_t pid, __u32 *personality)
+{
+	__do_close int fd = -EBADF;
+	int ret = -1;
+	char path[STRLITERALLEN("/proc//personality") + INTTYPE_TO_STRLEN(pid_t) + 1];
+	/* seq_printf(m, "%08x\n", task->personality); */
+	char buf[8 + 1];
+
+	ret = strnprintf(path, sizeof(path), "/proc/%d/personality", pid);
+	if (ret < 0)
+		return -1;
+
+	fd = open(path, O_RDONLY | O_CLOEXEC);
+	if (fd < 0)
+		return -1;
+
+	ret = read_nointr(fd, buf, sizeof(buf) - 1);
+	if (ret >= 0) {
+		buf[ret] = '\0';
+		if (safe_uint32(buf, personality, 16) < 0)
+			return log_error(-1, "Failed to convert personality %s", buf);
+	}
+
+	return ret;
+}
