@@ -62,6 +62,7 @@ extern FILE *fdopen_cached(int fd, const char *mode, void **caller_freed_buffer)
 extern DIR *opendir_flags(const char *path, int oflags);
 extern ssize_t write_nointr(int fd, const void *buf, size_t count);
 extern int safe_uint64(const char *numstr, uint64_t *converted, int base);
+extern int safe_uint32(const char *numstr, uint32_t *converted, int base);
 extern char *trim_whitespace_in_place(char *buffer);
 
 static inline bool file_exists(const char *f)
@@ -75,4 +76,7 @@ static inline bool file_exists(const char *f)
 #define PROTECT_OPEN (PROTECT_OPEN_WITH_TRAILING_SYMLINKS | O_NOFOLLOW)
 extern char *read_file_at(int dfd, const char *fnam, unsigned int o_flags);
 
+extern int get_task_personality(pid_t pid, __u32 *personality);
+extern int get_host_personality(__u32 *personality);
+
 #endif /* __LXCFS_UTILS_H */
